@@ -1,5 +1,4 @@
 # Copyright Cloudinary
-import time
 import cloudinary
 from cloudinary import utils
 import json
@@ -11,9 +10,6 @@ import urllib2
 
 _initialized = False
 
-def now():
-    return str(int(time.time()))
-
 def build_eager(transformations):
     eager = []
     for tr in utils.build_array(transformations):
@@ -34,7 +30,7 @@ def build_custom_headers(headers):
     return "\n".join(headers)
 
 def build_upload_params(**options):
-    params = {"timestamp": now(),
+    params = {"timestamp": utils.now(),
               "transformation": utils.generate_transformation_string(**options)[0],
               "public_id": options.get("public_id"),
               "callback": options.get("callback"),
@@ -48,6 +44,7 @@ def build_upload_params(**options):
               "headers": build_custom_headers(options.get("headers")),
               "eager": build_eager(options.get("eager")),
               "use_filename": options.get("use_filename"),
+              "invalidate": options.get("invalidate"),
               "notification_url": options.get("notification_url"),
               "eager_notification_url": options.get("eager_notification_url"),
               "eager_async": options.get("eager_async"),
@@ -58,17 +55,33 @@ def upload(file, **options):
     params = build_upload_params(**options)
     return call_api("upload", params, file = file, **options)
 
+def upload_image(file, **options):
+    result = upload(file, **options)
+    return cloudinary.CloudinaryImage(result["public_id"], version=str(result["version"]),
+        format=result["format"], metadata=result)
+
 def destroy(public_id, **options):
     params = {
-        "timestamp": now(),
+        "timestamp": utils.now(),
         "type": options.get("type"),
+        "invalidate": options.get("invalidate"),
         "public_id":    public_id
     }
     return call_api("destroy", params, **options)
 
+def rename(from_public_id, to_public_id, **options):
+    params = {
+        "timestamp": utils.now(),
+        "type": options.get("type"),
+        "overwrite": options.get("overwrite"),
+        "from_public_id": from_public_id,
+        "to_public_id": to_public_id
+    }
+    return call_api("rename", params, **options)
+
 def explicit(public_id, **options):
      params = {
-        "timestamp": now(),
+        "timestamp": utils.now(),
         "type": options.get("type"),
         "public_id": public_id,
         "callback": options.get("callback"),
@@ -79,7 +92,7 @@ def explicit(public_id, **options):
 
 def generate_sprite(tag, **options):
      params = {
-        "timestamp": now(),
+        "timestamp": utils.now(),
         "tag": tag,
         "async": options.get("async"),
         "notification_url": options.get("notification_url"),
@@ -89,7 +102,7 @@ def generate_sprite(tag, **options):
 
 def multi(tag, **options):
      params = {
-        "timestamp": now(),
+        "timestamp": utils.now(),
         "tag": tag,
         "format": options.get("format"),
         "async": options.get("async"),
@@ -100,7 +113,7 @@ def multi(tag, **options):
 
 def explode(public_id, **options):
      params = {
-        "timestamp": now(),
+        "timestamp": utils.now(),
         "public_id": public_id,
         "format": options.get("format"),
         "notification_url": options.get("notification_url"),
@@ -122,7 +135,7 @@ def replace_tag(tag, public_ids = [], **options):
 
 def call_tags_api(tag, command, public_ids = [], **options):
     params = {
-        "timestamp": now(),
+        "timestamp": utils.now(),
         "tag": tag,
         "public_ids": utils.build_array(public_ids),
         "command": command,
@@ -132,7 +145,7 @@ def call_tags_api(tag, command, public_ids = [], **options):
 
 TEXT_PARAMS = ["public_id", "font_family", "font_size", "font_color", "text_align", "font_weight", "font_style", "background", "opacity", "text_decoration"]
 def text(text, **options):
-    params = {"timestamp": now(), "text": text}
+    params = {"timestamp": utils.now(), "text": text}
     for key in TEXT_PARAMS:
         params[key] = options.get(key)
     return call_api("text", params, **options)
