@@ -6,6 +6,8 @@ import struct
 import uuid
 import base64
 import cloudinary
+import time
+import urllib
 
 """ @deprecated: use cloudinary.SHARED_CDN """
 SHARED_CDN = cloudinary.SHARED_CDN
@@ -91,6 +93,7 @@ def cloudinary_url(source, **options):
     format = options.pop("format", None)
     cdn_subdomain = options.pop("cdn_subdomain", cloudinary.config().cdn_subdomain)
     cname = options.pop("cname", cloudinary.config().cname)
+    shorten = options.pop("shorten", cloudinary.config().shorten)
 
     cloud_name = options.pop("cloud_name", cloudinary.config().cloud_name or None)
     if cloud_name == None:
@@ -125,6 +128,11 @@ def cloudinary_url(source, **options):
         if not private_cdn or (secure and secure_distribution == cloudinary.AKAMAI_SHARED_CDN):
             prefix += "/" + cloud_name
 
+    if shorten and resource_type == "image" and type == "upload":
+        resource_type = "iu"
+        type = ""          
+    if source.find("/") >= 0 and not re.match(r'^https?:/', source) and  not re.match(r'^v[0-9]+', source) and  not version:
+        version = "1"
     components = [prefix, resource_type, type, transformation, "v" + str(version) if version else "", source]
     source = re.sub(r'([^:])/+', r'\1/', "/".join(components))
     return (source, options)
@@ -149,4 +157,30 @@ def signed_preloaded_image(result):
     path = "/".join([result["resource_type"], "upload", "v" + result["version"], filename])
     return path + "#" + result["signature"]
 
+def now():
+  return str(int(time.time()))
+  
+def private_download_url(public_id, format, **options):
+  api_key = options.get("api_key", cloudinary.config().api_key)
+  if not api_key: raise Exception("Must supply api_key")
+  api_secret = options.get("api_secret", cloudinary.config().api_secret)
+  if not api_secret: raise Exception("Must supply api_secret")
 
+  cloudinary_params = {
+    "timestamp": now(), 
+    "public_id": public_id, 
+    "format": format, 
+    "type": options.get("type"),
+    "attachment": options.get("attachment"),
+    "expires_at": options.get("expires_at")
+  }
+
+  # Remove blank parameters
+  for k, v in cloudinary_params.items():
+    if not v:
+      del cloudinary_params[k]
+
+  cloudinary_params["signature"] = api_sign_request(cloudinary_params, api_secret)
+  cloudinary_params["api_key"] = api_key
+
+  return cloudinary_api_url("download", **options) + "?" + urllib.urlencode(cloudinary_params)
